<map version="freeplane 1.5.6">
<!--To view this file, download free mind mapping software Freeplane from https://www.freeplane.org -->
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p style=&quot;text-align: center&quot;&gt;&#xa;      &lt;a href=&quot;https://www.freeplane.org/wiki/index.php/Tutorial_Freeplane#Dashboard_for_GTD&quot;&gt;&lt;font size=&quot;5&quot;&gt;&lt;b&gt;D&lt;/b&gt;&lt;/font&gt;ingen&amp;#160;&lt;font size=&quot;5&quot;&gt;&lt;b&gt;G&lt;/b&gt;&lt;/font&gt;edaan &lt;font size=&quot;5&quot;&gt;&lt;b&gt;K&lt;/b&gt;&lt;/font&gt;rijgen&lt;/a&gt;&lt;br&gt;Met&lt;i&gt;&amp;#160;&lt;b&gt;Freeplane&lt;/b&gt;&lt;/i&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" FOLDED="false" ID="ID_1723255651" CREATED="1283093380553" MODIFIED="1320853980757" VGAP_QUANTITY="0.0 px" BACKGROUND_COLOR="#ffcc00"><hook NAME="MapStyle">
    <properties fit_to_viewport="false;"/>

<map_styles>
<stylenode LOCALIZED_TEXT="styles.root_node" STYLE="oval" UNIFORM_SHAPE="true" VGAP_QUANTITY="24.0 pt">
<font SIZE="24"/>
<stylenode LOCALIZED_TEXT="styles.predefined" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="default" FORMAT_AS_HYPERLINK="true" COLOR="#000000" STYLE="fork" MAX_WIDTH="600.0 px" MIN_WIDTH="1.0 px">
<font NAME="SansSerif" SIZE="8" BOLD="false" ITALIC="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.details"/>
<stylenode LOCALIZED_TEXT="defaultstyle.attributes">
<font SIZE="9"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.note"/>
<stylenode LOCALIZED_TEXT="defaultstyle.floating">
<edge STYLE="hide_edge"/>
<cloud COLOR="#f0f0f0" SHAPE="ROUND_RECT"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.user-defined" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="styles.topic" COLOR="#18898b" STYLE="fork">
<font NAME="Liberation Sans" SIZE="12" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subtopic" COLOR="#cc3300" STYLE="fork">
<font NAME="Liberation Sans" SIZE="12" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subsubtopic" COLOR="#669900">
<font NAME="Liberation Sans" SIZE="12" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.important">
<icon BUILTIN="yes"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.AutomaticLayout" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="AutomaticLayout.level.root" COLOR="#000000">
<font SIZE="20"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,1" COLOR="#0033ff">
<font SIZE="18"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,2" COLOR="#00b439">
<font SIZE="16"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,3" COLOR="#990000">
<font SIZE="14"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,4" COLOR="#111111">
<font SIZE="12"/>
</stylenode>
</stylenode>
</stylenode>
</map_styles>
</hook>
<hook NAME="AutomaticEdgeColor" COUNTER="4" RULE="ON_BRANCH_CREATION"/>
<edge STYLE="linear" WIDTH="1"/>
<node TEXT="Met minder" POSITION="left" ID="ID_892290459" CREATED="1318451679082" MODIFIED="1336121957827" HGAP_QUANTITY="213.0 px" VSHIFT_QUANTITY="30.0 px" COLOR="#0000ff" BACKGROUND_COLOR="#33ff00" STYLE="bubble">
<icon BUILTIN="idea"/>
<arrowlink SHAPE="CUBIC_CURVE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1129302195" STARTINCLINATION="132;0;" ENDINCLINATION="132;0;" STARTARROW="DEFAULT" ENDARROW="DEFAULT"/>
<font SIZE="12" BOLD="true" ITALIC="true"/>
<hook NAME="FreeNode"/>
<edge STYLE="hide_edge" COLOR="#007c00" WIDTH="3"/>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;img src=&quot;Images/doc/freeplaneApplications.png&quot;&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" POSITION="right" ID="ID_470539907" CREATED="1317967796222" MODIFIED="1336132579445" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="-195.0 px">
<edge STYLE="hide_edge" COLOR="#ff00ff" WIDTH="3"/>
<hook NAME="FreeNode"/>
<cloud COLOR="#f0f0f0" SHAPE="ROUND_RECT"/>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;https://www.freeplane.org/wiki/index.php/Scripting&quot;&gt;Programmeren&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_1100351552" CREATED="1317963664772" MODIFIED="1320854026933" HGAP_QUANTITY="-99.0 px" VSHIFT_QUANTITY="-168.0 px">
<hook NAME="FreeNode"/>
<richcontent TYPE="DETAILS" HIDDEN="true">

<html>
  <head>

  </head>
  <body>
    <p>
      Krachtige script
    </p>
    <p>
      taal om in te
    </p>
    <p>
      programmeren
    </p>
  </body>
</html>
</richcontent>
<edge COLOR="#007c00" WIDTH="3"/>
</node>
<node TEXT="Brainstormen" LOCALIZED_STYLE_REF="defaultstyle.floating" FOLDED="true" POSITION="right" ID="ID_747441325" CREATED="1317963460911" MODIFIED="1336121273942" HGAP_QUANTITY="200.0 px" VSHIFT_QUANTITY="-159.0 px">
<icon BUILTIN="family"/>
<arrowlink SHAPE="CUBIC_CURVE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" FONT_SIZE="16" FONT_FAMILY="Script MT Bold" DESTINATION="ID_1380673058" MIDDLE_LABEL="Bedenken" STARTINCLINATION="247;0;" ENDINCLINATION="148;-57;" STARTARROW="DEFAULT" ENDARROW="DEFAULT"/>
<hook NAME="FreeNode"/>
<richcontent TYPE="DETAILS" HIDDEN="true">

<html>
  <head>

  </head>
  <body>
    <p>
      Scrijf zoals je denkt..
    </p>
    <p>
      De standaard mind map
    </p>
  </body>
</html>
</richcontent>
<edge COLOR="#ff0000" WIDTH="3"/>
<node TEXT="central topic" ID="ID_1607807952" CREATED="1318450079927" MODIFIED="1318450164274">
<edge STYLE="linear"/>
<node TEXT="with" ID="ID_1232722180" CREATED="1318450103144" MODIFIED="1318450108729"/>
<node TEXT="sub" ID="ID_431013725" CREATED="1318450109593" MODIFIED="1318450114539"/>
<node TEXT="topics" ID="ID_870254490" CREATED="1318450115378" MODIFIED="1318450125281"/>
<node TEXT="as" ID="ID_1119376813" CREATED="1318450217732" MODIFIED="1318450225079">
<node TEXT="the" ID="ID_693432684" CREATED="1318450225084" MODIFIED="1318450230954">
<node TEXT="flow" ID="ID_924717182" CREATED="1318450230959" MODIFIED="1318450235039">
<node TEXT="goes" ID="ID_166052506" CREATED="1318450235044" MODIFIED="1318450238916"/>
</node>
</node>
</node>
</node>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;https://www.freeplane.org/wiki/index.php/Tutorial_Freeplane#Vault&quot;&gt;Beveiligen&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_803151767" CREATED="1317963651200" MODIFIED="1320851935569" HGAP_QUANTITY="-203.0 px" VSHIFT_QUANTITY="-110.0 px">
<icon BUILTIN="password"/>
<hook NAME="FreeNode"/>
<richcontent TYPE="DETAILS" HIDDEN="true">

<html>
  <head>

  </head>
  <body>
    <p>
      Informatiekluis
    </p>
  </body>
</html>
</richcontent>
<edge COLOR="#00007c" WIDTH="3"/>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;https://www.freeplane.org/wiki/index.php/Tutorial_Freeplane#SWOT_analysis&quot;&gt;Analyseren&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_1839755402" CREATED="1317963473454" MODIFIED="1320854021021" HGAP_QUANTITY="316.0 px" VSHIFT_QUANTITY="-96.0 px">
<icon BUILTIN="xmag"/>
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1839755402" STARTINCLINATION="45;-33;" ENDINCLINATION="45;-33;" STARTARROW="DEFAULT" ENDARROW="DEFAULT"/>
<hook NAME="FreeNode"/>
<richcontent TYPE="DETAILS" HIDDEN="true">

<html>
  <head>

  </head>
  <body>
    <p>
      Toon relaties
    </p>
  </body>
</html>
</richcontent>
<edge COLOR="#0000ff" WIDTH="3"/>
</node>
<node TEXT="=3+4" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_70607341" CREATED="1317967038914" MODIFIED="1320851972013" HGAP_QUANTITY="-288.0 px" VSHIFT_QUANTITY="-47.0 px">
<hook NAME="FreeNode"/>
<richcontent TYPE="DETAILS">

<html>
  <head>

  </head>
  <body>
    <p>
      <a href="https://www.freeplane.org/wiki/index.php/Formula">Berekenen</a>
    </p>
  </body>
</html>
</richcontent>
<edge COLOR="#ff0000" WIDTH="3"/>
</node>
<node TEXT="Doe meer" POSITION="right" ID="ID_1129302195" CREATED="1317972413136" MODIFIED="1336120108668" HGAP_QUANTITY="-189.0 px" VSHIFT_QUANTITY="-42.0 px" COLOR="#0000ff" BACKGROUND_COLOR="#33ff00" STYLE="bubble">
<icon BUILTIN="wizard"/>
<font SIZE="12" BOLD="true" ITALIC="true"/>
<edge STYLE="hide_edge" COLOR="#7c7c00" WIDTH="3"/>
<hook NAME="FreeNode"/>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;https://www.freeplane.org/wiki/index.php/Tutorial_Freeplane#Organize_your_collection&quot;&gt;Organiseren&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_1300937459" CREATED="1317963516276" MODIFIED="1336120493295" HGAP_QUANTITY="455.0 px" VSHIFT_QUANTITY="-38.0 px">
<icon BUILTIN="attach"/>
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1300937459" STARTINCLINATION="86;0;" ENDINCLINATION="86;0;" STARTARROW="DEFAULT" ENDARROW="NONE"/>
<hook NAME="FreeNode"/>
<edge COLOR="#00ff00" WIDTH="3"/>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;freeplaneTutorial.mm#ID_887149959&quot;&gt;Filteren&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_1380673058" CREATED="1317963795719" MODIFIED="1336121058473" HGAP_QUANTITY="538.0 px" VSHIFT_QUANTITY="29.0 px">
<hook NAME="FreeNode"/>
<edge COLOR="#7c007c" WIDTH="3"/>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;freeplaneTutorial.mm#ID_1047570728&quot;&gt;Waarschuwen&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_545955177" CREATED="1317963546352" MODIFIED="1320852032198" HGAP_QUANTITY="-314.0 px" VSHIFT_QUANTITY="40.0 px">
<icon BUILTIN="calendar"/>
<hook NAME="FreeNode"/>
<edge COLOR="#00ffff" WIDTH="3"/>
<richcontent TYPE="DETAILS" HIDDEN="true">

<html>
  <head>

  </head>
  <body>
    <p>
      Agenda functie
    </p>
  </body>
</html>
</richcontent>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;https://www.freeplane.org/wiki/index.php/Tutorial_Freeplane#Scientific_environment&quot;&gt;Schrijven&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_1510399467" CREATED="1317965217458" MODIFIED="1336121090266" HGAP_QUANTITY="484.0 px" VSHIFT_QUANTITY="94.0 px">
<icon BUILTIN="list"/>
<arrowlink SHAPE="CUBIC_CURVE" COLOR="#ff0000" WIDTH="4" TRANSPARENCY="255" FONT_SIZE="14" FONT_FAMILY="Britannic Bold" DESTINATION="ID_360719522" MIDDLE_LABEL="Delen" STARTINCLINATION="28;230;" ENDINCLINATION="16;224;" STARTARROW="NONE" ENDARROW="NONE"/>
<richcontent TYPE="DETAILS" HIDDEN="true">

<html>
  <head>

  </head>
  <body>
    <p>
      Ondersteuning voor
    </p>
    <p>
      schrijven en weten-
    </p>
    <p>
      schappelijke referenties
    </p>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
<edge COLOR="#007c7c" WIDTH="3"/>
</node>
<node TEXT="" POSITION="right" ID="ID_1132549453" CREATED="1455910822984" MODIFIED="1455910822989">
<edge COLOR="#808080"/>
<hook NAME="FirstGroupNode"/>
</node>
<node TEXT="Doe" POSITION="right" ID="ID_692068107" CREATED="1317972888300" MODIFIED="1336122192113" COLOR="#ffffff" BACKGROUND_COLOR="#999900" STYLE="bubble" HGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="30.0 px">
<icon BUILTIN="wizard"/>
<font SIZE="12" BOLD="true"/>
<edge STYLE="sharp_bezier" COLOR="#ff00ff" WIDTH="7"/>
<node TEXT="wat" ID="ID_1911860200" CREATED="1318453489510" MODIFIED="1320852825774" HGAP_QUANTITY="50.0 px" VSHIFT_QUANTITY="-10.0 px">
<edge WIDTH="1"/>
</node>
<node TEXT="je" ID="ID_885513842" CREATED="1318453440855" MODIFIED="1320852833795" HGAP_QUANTITY="50.0 px" VSHIFT_QUANTITY="-10.0 px">
<edge WIDTH="1"/>
</node>
<node TEXT="wilt" ID="ID_1053481930" CREATED="1318453447023" MODIFIED="1320852841041" HGAP_QUANTITY="50.0 px">
<edge WIDTH="1"/>
</node>
</node>
<node TEXT="Jouw&#xa;manier" POSITION="right" ID="ID_1333704057" CREATED="1317972906157" MODIFIED="1336122199991" HGAP_QUANTITY="10.0 px" VSHIFT_QUANTITY="10.0 px" COLOR="#ffffff" BACKGROUND_COLOR="#999900" STYLE="bubble">
<font SIZE="12" BOLD="true"/>
<edge STYLE="sharp_bezier" COLOR="#ff0000" WIDTH="5"/>
<cloud COLOR="#ffff33" SHAPE="ARC"/>
<node TEXT="op" ID="ID_1525382905" CREATED="1318453097317" MODIFIED="1320852886188">
<edge STYLE="horizontal" WIDTH="1"/>
</node>
<node TEXT="de manier" ID="ID_1287102772" CREATED="1318453647991" MODIFIED="1320852922801">
<edge STYLE="horizontal" WIDTH="1"/>
</node>
<node TEXT="die" ID="ID_1095910058" CREATED="1318453652398" MODIFIED="1320852896359">
<edge STYLE="horizontal" WIDTH="1"/>
</node>
<node TEXT="jij" ID="ID_135701980" CREATED="1318492240091" MODIFIED="1320852900602">
<edge STYLE="horizontal" WIDTH="1"/>
<font SIZE="12"/>
</node>
<node TEXT="wilt" ID="ID_1148165886" CREATED="1318527681673" MODIFIED="1320852906889" VSHIFT_QUANTITY="-10.0 px">
<edge STYLE="horizontal" WIDTH="1"/>
</node>
</node>
<node TEXT="" POSITION="right" ID="ID_706916456" CREATED="1455910822989" MODIFIED="1455910822989">
<edge COLOR="#808080"/>
<hook NAME="SummaryNode"/>
<node TEXT="" ID="ID_742181469" CREATED="1336120997196" MODIFIED="1455910822990" HGAP_QUANTITY="30.0 px">
<icon BUILTIN="ksmiletris"/>
<edge WIDTH="3"/>
</node>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;https://www.freeplane.org/wiki/index.php/Tutorial_Freeplane#Meeting_support&quot;&gt;Vergaderen&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_941087087" CREATED="1317963530737" MODIFIED="1336120196745" HGAP_QUANTITY="-237.0 px" VSHIFT_QUANTITY="108.0 px">
<icon BUILTIN="group"/>
<arrowlink SHAPE="CUBIC_CURVE" COLOR="#0000ff" WIDTH="3" TRANSPARENCY="255" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1100351552" STARTINCLINATION="-209;-29;" ENDINCLINATION="-189;0;" STARTARROW="NONE" ENDARROW="NONE"/>
<hook NAME="FreeNode"/>
<richcontent TYPE="DETAILS" HIDDEN="true">

<html>
  <head>

  </head>
  <body>
    <p>
      Simple and advanced meeting support
    </p>
    <p>
      for agenda planning, taking notes and
    </p>
    <p>
      keeping records.
    </p>
  </body>
</html>
</richcontent>
<edge COLOR="#ff00ff" WIDTH="3"/>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;http://www.kioo.nl/freeplane/CoreMeeting&quot;&gt;Beginner&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" ID="ID_184991784" CREATED="1317972712983" MODIFIED="1319316038308">
<icon BUILTIN="smiley-oh"/>
</node>
<node TEXT="Gevorderde" ID="ID_1404449457" CREATED="1317972719278" MODIFIED="1320852087687">
<icon BUILTIN="ksmiletris"/>
</node>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;https://www.freeplane.org/wiki/index.php/Examples&quot;&gt;Document&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_360719522" CREATED="1317966438145" MODIFIED="1318589645732" LINK="menuitem:_$GettingStartedAction$0" HGAP_QUANTITY="-2.0 px" VSHIFT_QUANTITY="149.0 px">
<hook NAME="FreeNode"/>
<richcontent TYPE="DETAILS" HIDDEN="true">

<html>
  <head>

  </head>
  <body>
    <p>
      Versatile support for efficient documenting.
    </p>
    <p>
      The Freeplane<a href="http://www.kioo.nl/freeplane/tutorial_en">&#160;quick reference</a>&#160;is an example.
    </p>
  </body>
</html>
</richcontent>
<edge COLOR="#7c7c00" WIDTH="3"/>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;freeplaneTutorial.mm#ID_1838680824&quot;&gt;Stylen&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_1875337895" CREATED="1317967170441" MODIFIED="1336121070282" HGAP_QUANTITY="425.0 px" VSHIFT_QUANTITY="185.0 px">
<arrowlink SHAPE="LINE" COLOR="#ff0000" WIDTH="2" TRANSPARENCY="255" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1875337895" STARTINCLINATION="32;38;" ENDINCLINATION="32;38;" STARTARROW="NONE" ENDARROW="NONE"/>
<hook NAME="FreeNode"/>
<edge COLOR="#0000ff" WIDTH="3"/>
</node>
<node TEXT="&lt;html&gt;&#xa;  &lt;head&gt;&#xa;&#xa;  &lt;/head&gt;&#xa;  &lt;body&gt;&#xa;    &lt;p&gt;&#xa;      &lt;a href=&quot;https://www.freeplane.org/wiki/index.php/Tutorial_Freeplane#School_environment&quot;&gt;Leren&lt;/a&gt;&#xa;    &lt;/p&gt;&#xa;  &lt;/body&gt;&#xa;&lt;/html&gt;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_1583240168" CREATED="1317963552842" MODIFIED="1320852177980" HGAP_QUANTITY="110.0 px" VSHIFT_QUANTITY="208.0 px">
<icon BUILTIN="male1"/>
<arrowlink SHAPE="LINE" COLOR="#ff0000" WIDTH="2" TRANSPARENCY="255" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1583240168" STARTINCLINATION="-9;57;" ENDINCLINATION="-9;57;" STARTARROW="NONE" ENDARROW="NONE"/>
<hook NAME="FreeNode"/>
<richcontent TYPE="DETAILS" HIDDEN="true">

<html>
  <head>

  </head>
  <body>
    <p>
      Een opdracht en
    </p>
    <p>
      afgeschermde
    </p>
    <p>
      oplossingen
    </p>
  </body>
</html>
</richcontent>
<edge COLOR="#ffff00" WIDTH="3"/>
</node>
<node TEXT="Presenteren" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="right" ID="ID_501841034" CREATED="1317963565525" MODIFIED="1336121085945" HGAP_QUANTITY="227.0 px" VSHIFT_QUANTITY="250.0 px">
<arrowlink SHAPE="LINE" COLOR="#ff0033" WIDTH="2" TRANSPARENCY="255" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_501841034" STARTINCLINATION="-2;53;" ENDINCLINATION="-2;53;" STARTARROW="NONE" ENDARROW="NONE"/>
<hook NAME="FreeNode"/>
<edge COLOR="#7c0000" WIDTH="3"/>
</node>
</node>
</map>
